@@ -26,14 +26,11 @@
 
 #include "config.h"
 
-#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)
-#include <sys/param.h>
-#include <sys/mount.h>
-#else
-#include <sys/vfs.h>
-#endif /* __FreeBSD__ || __NetBSD__ || __OpenBSD__ */
 #include <sys/types.h>
 #include <sys/stat.h>
+#ifdef sun
+#include <sys/statfs.h>
+#endif
 #include <time.h>
 #include <errno.h>
 #include <stdio.h>
